@@ -102,43 +102,3 @@ def rate_limited(max_per_second: Optional[Union[int, float]]) \
         return rate_limited_function
 
     return decorate
-
-
-@rate_limited(2)
-def _test_print_2hz(num: int) -> None:
-    log.info(f"_test_print_2hz: {num}")
-
-
-@rate_limited(5)
-def _test_print_5hz(num: int) -> None:
-    log.info(f"_test_print_5hz: {num}")
-
-
-def _test_print(num: int) -> None:
-    log.info(f"_test_print: {num}")
-
-
-def test_rate_limiter() -> None:
-    """
-    Test the rate-limiting functions.
-    """
-    n = 10
-    log.warning("Via decorator, 2 Hz")
-    for i in range(1, n + 1):
-        _test_print_2hz(i)
-    log.warning("Via decorator, 5 Hz")
-    for i in range(1, n + 1):
-        _test_print_5hz(i)
-    log.warning("Created dynamically, 10 Hz")
-    tenhz = rate_limited(10)(_test_print)
-    for i in range(1, n + 1):
-        tenhz(i)
-    log.warning("Created dynamically, unlimited")
-    unlimited = rate_limited(None)(_test_print)
-    for i in range(1, n + 1):
-        unlimited(i)
-
-
-if __name__ == "__main__":
-    main_only_quicksetup_rootlogger(level=logging.DEBUG)
-    test_rate_limiter()
