@@ -414,7 +414,7 @@ def add_index(engine: Engine,
         raise ValueError(
             f"add_index: Use either sqla_column or multiple_sqla_columns, "
             f"not both (sqla_column = {sqla_column!r}, "
-            f"multiple_sqla_columns = {multiple_sqla_columns!r}"
+            f"multiple_sqla_columns = {multiple_sqla_columns!r})"
         )
     if sqla_column is not None:
         colnames = [sqla_column.name]
@@ -488,7 +488,7 @@ def add_index(engine: Engine,
                 raise ValueError(
                     f"To make a FULLTEXT index under SQL Server, we need to "
                     f"know the name of the PK index, but couldn't find one "
-                    f"from get_pk_index_name() for table {tablename!r}")
+                    f"via mssql_get_pk_index_name() for table {tablename!r}")
             # We don't name the FULLTEXT index itself, but it has to relate
             # to an existing unique index.
             sql = (
@@ -1157,62 +1157,3 @@ def index_lists_equal(a: List[Index], b: List[Index]) -> bool:
             log.debug("Mismatch: {!r} != {!r}", a[i], b[i])
             return False
     return True
-
-
-# =============================================================================
-# Tests
-# =============================================================================
-
-def test_assert(x, y) -> None:
-    try:
-        assert x == y
-    except AssertionError:
-        print(f"{x!r} should have been {y!r}")
-        raise
-
-
-def unit_tests() -> None:
-    from sqlalchemy.dialects.mssql.base import MSDialect
-    from sqlalchemy.dialects.mysql.base import MySQLDialect
-    d_mssql = MSDialect()
-    d_mysql = MySQLDialect()
-    col1 = Column('hello', BigInteger, nullable=True)
-    col2 = Column('world', BigInteger,
-                  autoincrement=True)  # does NOT generate IDENTITY
-    col3 = make_bigint_autoincrement_column('you', d_mssql)
-    metadata = MetaData()
-    t = Table('mytable', metadata)
-    t.append_column(col1)
-    t.append_column(col2)
-    t.append_column(col3)
-
-    print("Checking Column -> DDL: SQL Server (mssql)")
-    test_assert(column_creation_ddl(col1, d_mssql), "hello BIGINT NULL")
-    test_assert(column_creation_ddl(col2, d_mssql), "world BIGINT NULL")
-    test_assert(column_creation_ddl(col3, d_mssql),
-                "you BIGINT NOT NULL IDENTITY(1,1)")
-
-    print("Checking Column -> DDL: MySQL (mysql)")
-    test_assert(column_creation_ddl(col1, d_mysql), "hello BIGINT")
-    test_assert(column_creation_ddl(col2, d_mysql), "world BIGINT")
-    # not col3; unsupported
-
-    print("Checking SQL type -> SQL Alchemy type")
-    to_check = [
-        # mssql
-        ("BIGINT", d_mssql),
-        ("NVARCHAR(32)", d_mssql),
-        ("NVARCHAR(MAX)", d_mssql),
-        ('NVARCHAR(160) COLLATE "Latin1_General_CI_AS"', d_mssql),
-        # mysql
-        ("BIGINT", d_mssql),
-        ("LONGTEXT", d_mysql),
-        ("ENUM('red','green','blue')", d_mysql),
-    ]
-    for coltype, dialect in to_check:
-        print(f"... {coltype!r} -> dialect {dialect.name!r} -> "
-              f"{get_sqla_coltype_from_dialect_str(coltype, dialect)!r}")
-
-
-if __name__ == '__main__':
-    unit_tests()
